Backers who have funded Weblate
+++++++++++++++++++++++++++++++

List of Weblate supporters from 
`Bountysource <https://salt.bountysource.com/teams/weblate>`_:

* Yashiro Ccs
* Cheng-Chia Tseng
* Timon Reinhard
* `Cassidy James <https://cassidyjames.com/>`_
* Loic Dachary
